@@ -12,7 +12,7 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-""" Brick Connector objects for each supported transport protocol.
+"""Brick Connector objects for each supported transport protocol.
 
 .. module: connector
 
@@ -148,8 +148,20 @@ _connector_mapping_linux = {
 # Mapping for the S390X platform
 _connector_mapping_linux_s390x = {
     initiator.FIBRE_CHANNEL:
-        ('os_brick.initiator.connectors.fibre_channel_s390x.'
-         'FibreChannelConnectorS390X'),
+        'os_brick.initiator.connectors.fibre_channel_s390x.'
+        'FibreChannelConnectorS390X',
+    initiator.DRBD:
+        'os_brick.initiator.connectors.drbd.DRBDConnector',
+    initiator.NFS:
+        'os_brick.initiator.connectors.remotefs.RemoteFsConnector',
+    initiator.ISCSI:
+        'os_brick.initiator.connectors.iscsi.ISCSIConnector',
+    initiator.LOCAL:
+        'os_brick.initiator.connectors.local.LocalConnector',
+    initiator.RBD:
+        'os_brick.initiator.connectors.rbd.RBDConnector',
+    initiator.GPFS:
+        'os_brick.initiator.connectors.gpfs.GPFSConnector',
 }
 
 # Mapping for the windows connectors
@@ -163,6 +175,14 @@ _connector_mapping_windows = {
 }
 
 
+# Create aliases to the old names until 2.0.0
+# TODO(smcginnis) Remove this lookup once unit test code is updated to
+# point to the correct location
+for item in connector_list:
+    _name = item.split('.')[-1]
+    globals()[_name] = importutils.import_class(item)
+
+
 @utils.trace
 def get_connector_properties(root_helper, my_ip, multipath, enforce_multipath,
                              host=None, execute=None):
